@@ -18,7 +18,6 @@ from typing import Optional, Dict, Callable, Any
 from requests import exceptions
 
 import vertopal
-from vertopal.utils.config import Config
 
 
 class Terminal:
@@ -42,8 +41,8 @@ class Terminal:
         >>> Terminal.silent = True # Don't write to stdout & stderr
         >>> Terminal.output_dir = "/home/vertopal/convert_output"
         >>> Terminal.convert(
-        ...     input="my_document.docx"
-        ...     output_format="txt-markdown"
+        ...     input="my_document.docx",
+        ...     output_format="txt-markdown",
         ... )
     """
 
@@ -75,15 +74,15 @@ class Terminal:
         ],
     }
 
-    app_id: str = Config.read("api", "appid")
-    security_token: str = Config.read("api", "token")
+    app_id: str = ""
+    security_token: str = ""
 
     @classmethod
     def convert(
-            cls,
-            input_file: str,
-            output_format: str,
-            input_format: Optional[str] = None
+        cls,
+        input_file: str,
+        output_format: str,
+        input_format: Optional[str] = None,
     ) -> None:
         """Convert file by running upload, convert, and download tasks.
 
@@ -105,6 +104,8 @@ class Terminal:
         sleep_secs = (10, 20, 30, 60)
         sleep_step = 0
 
+        vertopal.API.set_ua_product_name(vertopal.API.UA_CLI)
+
         cls._step(f"Uploading {filename}", "1/4")
         upload_connector = cls._upload(filename, filepath)
 
@@ -137,7 +138,6 @@ class Terminal:
                 "Conversion failed. To learn more, visit: "
                 "https://www.vertopal.com/en/help/post/27",
                 "CONVERT_FAILED",
-                end="",
             )
             cls.exit(cls.EX_CONVERT_FAILED)
 
@@ -147,7 +147,7 @@ class Terminal:
             cls._download_file(download.connector, download.filename)
 
         else:
-            cls._error("An unexpected error happened", end="")
+            cls._error("An unexpected error happened")
             cls.exit(cls.EX_OTHER)
 
     @classmethod
@@ -191,17 +191,16 @@ class Terminal:
         try:
             response = func(**kwargs)
         except FileNotFoundError:
-            cls._error("Input file not exists.", end="")
+            cls._error("Input file not exists.")
             cls.exit(cls.EX_INPUT_NOT_FOUND)
         except exceptions.ConnectionError:
             cls._error(
                 f"Cannot reach API endpoint ({vertopal.API.ENDPOINT}). "
                 "Please check your network connection.",
-                end=""
             )
             cls.exit(cls.EX_CONNECTION_ERROR)
         except Exception as error: # pylint: disable=broad-except
-            cls._error(repr(error), end="")
+            cls._error(repr(error))
             cls.exit(cls.EX_OTHER)
         else:
             try:
@@ -210,15 +209,14 @@ class Terminal:
                 cls._error(
                     "Cannot decode HTTP response",
                     "INVALID_JSON",
-                    end="",
                 )
                 cls.exit(cls.EX_INVALID_JSON_RESPONSE)
             except Exception as error: # pylint: disable=broad-except
-                cls._error(repr(error), end="")
+                cls._error(repr(error))
                 cls.exit(cls.EX_OTHER)
             # if http response code is 4xx or 5xx
             if (response.status_code % 1000) // 100 in (4, 5):
-                cls._error(json["message"], json["code"], end="")
+                cls._error(json["message"], json["code"])
                 cls.exit(cls.EX_API_RESPONSE_ERROR)
             else:
                 if json["result"]["warning"]:
@@ -234,7 +232,6 @@ class Terminal:
                     cls._error(
                         json["result"]["error"]["message"],
                         json["result"]["error"]["code"],
-                        end="",
                     )
                     cls.exit(cls.EX_API_RESPONSE_ERROR)
             return json
@@ -297,7 +294,7 @@ class Terminal:
         if json["entity"]["status"] == "running":
             return json["entity"]["id"]
 
-        cls._error("Entity status is not running.", end="")
+        cls._error("Entity status is not running.")
         cls.exit(cls.EX_OTHER)
         return ""
 
@@ -404,9 +401,9 @@ class Terminal:
             else:
                 output = cls._get_output_path(filename)
                 try:
-                    with open(output, 'wb') as fd:
+                    with open(output, 'wb') as file:
                         for chunk in response.iter_content(chunk_size=128):
-                            fd.write(chunk)
+                            file.write(chunk)
                 except Exception as error: # pylint: disable=broad-except
                     cls._error(repr(error))
                     cls.exit(cls.EX_FILE_WRITE_ERROR)
@@ -444,7 +441,7 @@ class Terminal:
 
         if cls.silent:
             return
-        line = f"[DONE] Your converted file saved as {str(filename)}"
+        line = f"[DONE] Your converted file saved as {str(filename)}\n"
         sys.stdout.write(line)
 
     @classmethod
@@ -631,6 +628,16 @@ class Terminal:
             metavar="<directory>",
             help="directory for saving converted file"
         )
+        args_convert.add_argument(
+            "--app",
+            metavar="<app-id>",
+            help="override Application ID in global config file"
+        )
+        args_convert.add_argument(
+            "--token",
+            metavar="<token>",
+            help="override Security Token in global config file"
+        )
         args_convert.add_argument(
             "--overwrite",
             action="store_true",
